@@ -22,7 +22,7 @@ use warnings;
 use XML::LibXML qw/:libxml/;
 use Carp;
 
-our $VERSION = '2.06';
+our $VERSION = '2.07';
 
 =head2 B<parse> (F<string>)
 
@@ -30,8 +30,8 @@ Return a perl structure from a XML string, if it's
 parsable, otherwise return a raw XML::LibXML object
 
 =cut
-sub parse
-{
+
+sub parse {
 	my $xml = shift;
 
 	my @tree = eval { parsetree ($xml) };
@@ -44,8 +44,8 @@ sub parse
 Parse a XML node tree recursively.
 
 =cut
-sub parsetree
-{
+
+sub parsetree {
 	my $xml = shift;
 	my @retval;
 
